Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(103)

Unified Diff: src/compiler/code-generator.cc

Issue 782703002: Cleanup deoptimizer relocation slot preparation. (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: Comment for x87 port. Created 6 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/compiler/code-generator.h ('k') | src/compiler/ia32/code-generator-ia32.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/compiler/code-generator.cc
diff --git a/src/compiler/code-generator.cc b/src/compiler/code-generator.cc
index 4f13b4cfe5beee4c78727d1ec086bab457036808..09438f912e35c8fe23e43d67423200a46a1fb83c 100644
--- a/src/compiler/code-generator.cc
+++ b/src/compiler/code-generator.cc
@@ -84,7 +84,7 @@ Handle<Code> CodeGenerator::GenerateCode() {
FinishCode(masm());
// Ensure there is space for lazy deopt.
if (!info->IsStub()) {
int target_offset = masm()->pc_offset() + Deoptimizer::patch_size();
while (masm()->pc_offset() < target_offset) {
@@ -107,7 +107,10 @@ Handle<Code> CodeGenerator::GenerateCode() {
PopulateDeoptimizationData(result);
- EnsureRelocSpaceForLazyDeopt(result);
+ // Ensure there is space for lazy deoptimization in the relocation info.
+ if (!info->IsStub()) {
+ Deoptimizer::EnsureRelocSpaceForLazyDeoptimization(result);
+ }
// Emit a code line info recording stop event.
void* line_info = recorder->DetachJITHandlerData();
« no previous file with comments | « src/compiler/code-generator.h ('k') | src/compiler/ia32/code-generator-ia32.cc » ('j') | no next file with comments »
@@ -84,7 +84,7 @@ Handle<Code> CodeGenerator::GenerateCode() {
FinishCode(masm());
- // Ensure there is space for lazy deopt.
+ // Ensure there is space for lazy deoptimization in the code.
if (!info->IsStub()) {
int target_offset = masm()->pc_offset() + Deoptimizer::patch_size();

Powered by Google App Engine
This is Rietveld 408576698